nengo\_spa\.networks
====================

.. automodule:: nengo_spa.networks
   :members:
   :imported-members:

   .. autosummary::

      CircularConvolution
      IdentityEnsembleArray

   .. rubric:: Selection networks

   .. autosummary::
      selection.IA
      selection.Thresholding
      selection.WTA


nengo\_spa\.networks\.selection
-------------------------------

.. automodule:: nengo_spa.networks.selection
   :members:
